<?php

namespace Skynettechnologies\AllInOneAccessibility\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Skynettechnologies\AllInOneAccessibility\Interfaces\AIOASettingsRepositoryInterface;
use Skynettechnologies\AllInOneAccessibility\Repositories\Eloquent\Filters\AIOASettingsPublicFilter;
use Skynettechnologies\AllInOneAccessibility\Repositories\Eloquent\Presenters\AIOASettingsListPresenter;

class AIOASettingsPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        AIOASettingsRepositoryInterface $a_i_o_a_settings
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('skynettechnologies.all_in_one_accessibility.modules'), 'a_i_o_a_settings', guard_url('a_i_o_a_settings'));
        $this->repository = $a_i_o_a_settings;
    }

    /**
     * Show a_i_o_a_settings's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(AIOASettingsPublicFilter::class)
            ->setPresenter(AIOASettingsListPresenter::class)
            ->select('a_i_o_a_settings.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('all_in_one_accessibility::a_i_o_a_settings.names'))
            ->view('all_in_one_accessibility::public.a_i_o_a_settings.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show a_i_o_a_settings.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('all_in_one_accessibility::a_i_o_a_settings.name'))
            ->view('all_in_one_accessibility::public.a_i_o_a_settings.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
