<?php

namespace Skynettechnologies\AllInOneAccessibility\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Repository\Filter\RequestFilter;
use Skynettechnologies\AllInOneAccessibility\Forms\AIOASettings as AIOASettingsForm;
use Skynettechnologies\AllInOneAccessibility\Http\Requests\AIOASettingsRequest;
use Skynettechnologies\AllInOneAccessibility\Interfaces\AIOASettingsRepositoryInterface;
use Skynettechnologies\AllInOneAccessibility\Repositories\Eloquent\Filters\AIOASettingsResourceFilter;
use Skynettechnologies\AllInOneAccessibility\Repositories\Eloquent\Presenters\AIOASettingsListPresenter;

/**
 * Resource controller class for a_i_o_a_settings.
 */
class AIOASettingsResourceController extends BaseController
{

    /**
     * Initialize a_i_o_a_settings resource controller.
     *
     *
     * @return null
     */
    public function __construct(AIOASettingsRepositoryInterface $a_i_o_a_settings)
    {
        parent::__construct();
        $this->form = AIOASettingsForm::setAttributes()->toArray();
        $this->modules = $this->modules(config('skynettechnologies.all_in_one_accessibility.modules'), 'all_in_one_accessibility', guard_url('all_in_one_accessibility'));
        $this->repository = $a_i_o_a_settings;
    }

    /**
     * Display a list of a_i_o_a_settings.
     *
     * @return Response
     */
    public function index(AIOASettingsRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(AIOASettingsResourceFilter::class)
            ->setPresenter(AIOASettingsListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('all_in_one_accessibility::a_i_o_a_settings.names'))
            ->view('all_in_one_accessibility::a_i_o_a_settings.index')
            ->data(compact('data', 'meta', 'links', 'modules', 'form'))
            ->output();
    }

    /**
     * Display a_i_o_a_settings.
     *
     * @param Request $request
     * @param Model   $a_i_o_a_settings
     *
     * @return Response
     */
    public function show(AIOASettingsRequest $request, AIOASettingsRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('all_in_one_accessibility::a_i_o_a_settings.name'))
            ->data(compact('data', 'form', 'modules', 'form'))
            ->view('all_in_one_accessibility::a_i_o_a_settings.show')
            ->output();
    }

    /**
     * Show the form for creating a new a_i_o_a_settings.
     *
     * @param Request $request
     *x
     * @return Response
     */
    public function create(AIOASettingsRequest $request, AIOASettingsRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('all_in_one_accessibility::a_i_o_a_settings.name'))
            ->view('all_in_one_accessibility::a_i_o_a_settings.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Create new a_i_o_a_settings.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AIOASettingsRequest $request, AIOASettingsRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $repository->create($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.created', ['Module' => trans('all_in_one_accessibility::a_i_o_a_settings.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('all_in_one_accessibility/a_i_o_a_settings/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/all_in_one_accessibility/a_i_o_a_settings'))
                ->redirect();
        }

    }

    /**
     * Show a_i_o_a_settings for editing.
     *
     * @param Request $request
     * @param Model   $a_i_o_a_settings
     *
     * @return Response
     */
    public function edit(AIOASettingsRequest $request, AIOASettingsRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('all_in_one_accessibility::a_i_o_a_settings.name'))
            ->view('all_in_one_accessibility::a_i_o_a_settings.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Update the a_i_o_a_settings.
     *
     * @param Request $request
     * @param Model   $a_i_o_a_settings
     *
     * @return Response
     */
    public function update(AIOASettingsRequest $request, AIOASettingsRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $repository->update($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('all_in_one_accessibility::a_i_o_a_settings.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('all_in_one_accessibility/a_i_o_a_settings/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('all_in_one_accessibility/a_i_o_a_settings/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the a_i_o_a_settings.
     *
     * @param Model   $a_i_o_a_settings
     *
     * @return Response
     */
    public function destroy(AIOASettingsRequest $request, AIOASettingsRepositoryInterface $repository)
    {
        try {
            $repository->delete();
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('all_in_one_accessibility::a_i_o_a_settings.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('all_in_one_accessibility/a_i_o_a_settings/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('all_in_one_accessibility/a_i_o_a_settings/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }
}
