<?php

namespace Skynettechnologies\AllInOneAccessibility\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Skynettechnologies\AllInOneAccessibility\Http\Requests\AIOASettingsRequest;
use Skynettechnologies\AllInOneAccessibility\Models\AIOASettings;

/**
 * Admin web controller class.
 */
class AIOASettingsWorkflowController extends BaseController
{

    /**
     * Workflow controller function for a_i_o_a_settings.
     *
     * @param Model   $a_i_o_a_settings
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(AIOASettingsRequest $request, AIOASettings $a_i_o_a_settings, $step)
    {

        try {

            $a_i_o_a_settings->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('all_in_one_accessibility::a_i_o_a_settings.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/a_i_o_a_settings/a_i_o_a_settings/' . $a_i_o_a_settings->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/a_i_o_a_settings/a_i_o_a_settings/' . $a_i_o_a_settings->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for a_i_o_a_settings.
     *
     * @param Model   $a_i_o_a_settings
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(AIOASettings $a_i_o_a_settings, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $a_i_o_a_settings->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('all_in_one_accessibility::a_i_o_a_settings.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('all_in_one_accessibility::admin.a_i_o_a_settings.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('all_in_one_accessibility::admin.a_i_o_a_settings.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('all_in_one_accessibility::admin.a_i_o_a_settings.message', $data)->render();

        }

    }
}
