<?php

namespace Skynettechnologies\AllInOneAccessibility\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Skynettechnologies\AllInOneAccessibility\Models\AIOASettings;

class AIOASettingsPolicy
{

    /**
     * Determine if the given user can view the a_i_o_a_settings.
     *
     * @param UserPolicyInterface $authUser
     * @param AIOASettings $a_i_o_a_settings
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, AIOASettings $a_i_o_a_settings)
    {
        if ($authUser->canDo('all_in_one_accessibility.a_i_o_a_settings.view') && $authUser->isAdmin()) {
            return true;
        }

        return $a_i_o_a_settings->user_id == user_id() && $a_i_o_a_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can create a a_i_o_a_settings.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('all_in_one_accessibility.a_i_o_a_settings.create');
    }

    /**
     * Determine if the given user can update the given a_i_o_a_settings.
     *
     * @param UserPolicyInterface $authUser
     * @param AIOASettings $a_i_o_a_settings
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, AIOASettings $a_i_o_a_settings)
    {
        if ($authUser->canDo('all_in_one_accessibility.a_i_o_a_settings.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $a_i_o_a_settings->user_id == user_id() && $a_i_o_a_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given a_i_o_a_settings.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, AIOASettings $a_i_o_a_settings)
    {
        return $a_i_o_a_settings->user_id == user_id() && $a_i_o_a_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given a_i_o_a_settings.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, AIOASettings $a_i_o_a_settings)
    {
        if ($authUser->canDo('all_in_one_accessibility.a_i_o_a_settings.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given a_i_o_a_settings.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, AIOASettings $a_i_o_a_settings)
    {
        if ($authUser->canDo('all_in_one_accessibility.a_i_o_a_settings.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
