<?php

namespace Skynettechnologies\AllInOneAccessibility\Providers;

use Illuminate\Support\ServiceProvider;
use Skynettechnologies\AllInOneAccessibility\AllInOneAccessibility;

class AllInOneAccessibilityServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'all_in_one_accessibility');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'all_in_one_accessibility');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Skynettechnologies\AllInOneAccessibility\Providers\AuthServiceProvider::class);
        $this->app->register(\Skynettechnologies\AllInOneAccessibility\Providers\RouteServiceProvider::class);
        // $this->app->register(\Skynettechnologies\AllInOneAccessibility\Providers\EventServiceProvider::class);
        // $this->app->register(\Skynettechnologies\AllInOneAccessibility\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('skynettechnologies.all_in_one_accessibility', function($app)
        {
            return $this->app->make(AllInOneAccessibility::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
                // Bind AIOASettings to repository
        $this->app->bind(
            'Skynettechnologies\AllInOneAccessibility\Interfaces\AIOASettingsRepositoryInterface',
            \Skynettechnologies\AllInOneAccessibility\Repositories\Eloquent\AIOASettingsRepository::class
        );
    }


    /**
     * Merges user's and all_in_one_accessibility's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'skynettechnologies.all_in_one_accessibility'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Skynettechnologies\AllInOneAccessibility\Commands\AllInOneAccessibility::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['skynettechnologies.all_in_one_accessibility'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('skynettechnologies/all_in_one_accessibility.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/all_in_one_accessibility')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/all_in_one_accessibility')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
