<?php

namespace Skynettechnologies\AllInOneAccessibility\Workflow;

use Skynettechnologies\AllInOneAccessibility\Models\AIOASettings;
use Validator;

class AIOASettingsValidator
{

    /**
     * Determine if the given a_i_o_a_settings is valid for complete status.
     *
     * @param AIOASettings $a_i_o_a_settings
     *
     * @return bool / Validator
     */
    public function complete(AIOASettings $a_i_o_a_settings)
    {
        return Validator::make($a_i_o_a_settings->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given a_i_o_a_settings is valid for verify status.
     *
     * @param AIOASettings $a_i_o_a_settings
     *
     * @return bool / Validator
     */
    public function verify(AIOASettings $a_i_o_a_settings)
    {
        return Validator::make($a_i_o_a_settings->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given a_i_o_a_settings is valid for approve status.
     *
     * @param AIOASettings $a_i_o_a_settings
     *
     * @return bool / Validator
     */
    public function approve(AIOASettings $a_i_o_a_settings)
    {
        return Validator::make($a_i_o_a_settings->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given a_i_o_a_settings is valid for publish status.
     *
     * @param AIOASettings $a_i_o_a_settings
     *
     * @return bool / Validator
     */
    public function publish(AIOASettings $a_i_o_a_settings)
    {
        return Validator::make($a_i_o_a_settings->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given a_i_o_a_settings is valid for archive status.
     *
     * @param AIOASettings $a_i_o_a_settings
     *
     * @return bool / Validator
     */
    public function archive(AIOASettings $a_i_o_a_settings)
    {
        return Validator::make($a_i_o_a_settings->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given a_i_o_a_settings is valid for unpublish status.
     *
     * @param AIOASettings $a_i_o_a_settings
     *
     * @return bool / Validator
     */
    public function unpublish(AIOASettings $a_i_o_a_settings)
    {
        return Validator::make($a_i_o_a_settings->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
